import argparse
import os
import shutil

def main():
    ap = argparse.ArgumentParser()
    ap.add_argument('steamdir', type=str, help='Path to the steam workshop directory of starbound ("*STEAM_LIBRARY_PATH*/steamapps/workshop/content/211820")')
    ap.add_argument('sbdir', type=str, help='Path to the starbound mods directory ("*STEAM_LIBRARY_PATH*/steamapps/common/Starbound/mods")')
    args = ap.parse_args()

    for mod in os.listdir(args.steamdir):
        if os.path.isfile(os.path.join(args.steamdir, mod, 'contents.pak')):
            shutil.copy2(os.path.join(args.steamdir, mod, 'contents.pak'), os.path.join(args.sbdir, mod + '.pak'))
        else:
            print('Skipping ' + mod + ' (no "contents.pak" found)!')



from setuptools import setup

with open('README.md', 'r') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name='steam2starbound',
    version='1.0.0',
    description='Copies mods from steam workshop to the starbound directory.',
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    url='https://git.brokenmouse.studio/ever/steam2starbound',
    author='EV3R4',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: System Administrators',
        'Topic :: Games/Entertainment',
        'Topic :: Utilities',

        'License :: OSI Approved :: MIT License',

        'Operating System :: OS Independent',

        'Natural Language :: English',
    ],
    keywords=['starbound'],
    packages=['steam2starbound'],
    install_requires=[],
    entry_points={
        'console_scripts': [
            'steam2starbound=steam2starbound.__main__:main',
        ],
    },
)
